##  Changing or Unlinking Linked Items
You can link a fact sheet to a different catalog item if there is a more appropriate one or if it was inadvertently linked to the current item.
To change linked items in bulk from the reference catalog page, follow these steps:
  1. In the reference catalog, go to the Linked tab.
  2. Select a fact sheet for which you want to change the linked item.
  3. Search for and select a different catalog item from the drop-down menu on the right.
  4. Click Change Link.


To change the linked item for a single fact sheet, follow these steps:
  1. On the right-side pane of the business capability fact sheet, under Reference Catalog, click Linked.
  2. On the page that appears, search for a different catalog item using the search field on the left, select an item to link, then click Change Link.


If needed, you can unlink multiple fact sheets from the reference catalog page in bulk. Similarly, you can unlink a specific fact sheet from the fact sheet page.
